pub fn write_cstr(
input: &[&[u8]],
output: &mut MutableUserMemory<'_, '_, '_>,
) -> u64Expand description
Writes a NUL-terminated C string assembled from slices into user memory.
Return value has the same semantics as snprintf.
pub fn write_cstr(
input: &[&[u8]],
output: &mut MutableUserMemory<'_, '_, '_>,
) -> u64Writes a NUL-terminated C string assembled from slices into user memory.
Return value has the same semantics as snprintf.