pub struct UnboundProgram { /* private fields */ }Expand description
A loaded program that is not yet pinned to a thread.
Implementations
Sourceimpl UnboundProgram
impl UnboundProgram
Sourcepub fn pin_to_current_thread(self, t: ThreadEnv) -> Program
pub fn pin_to_current_thread(self, t: ThreadEnv) -> Program
Pins the program to the current thread using a prepared ThreadEnv.